---
name: Issue
about: Please only raise an issue if you've been advised to do so after discussion. Much appreciated! 🙏
---

The starting point for issues should usually be a discussion...

https://github.com/orgs/poulet-lab/discussions

Potential bugs may be raised as a "Potential Issue" discussion. The feature requests may be raised as an
"Ideas" discussion.

We can then decide if the discussion needs to be escalated into an "Issue" or not.

This will make sure that everything is organized properly.
---

**poulet_py version**:
**Python version**:
**OS**:
**Platform**:

<!-- Enter your issue details below this comment and as much detail as possible. -->
